@@ -88,7 +88,7 @@ static int asteroid_updateSingle( Asteroid *a )
    int                   forced;
    int                   setvel = 0;
 
-   /* Push back towards center. */
+   /* Push back towards centre. */
    offx = ast->pos.x - a->sol.pos.x;
    offy = ast->pos.y - a->sol.pos.y;
    d    = pow2( offx ) + pow2( offy );
@@ -246,8 +246,8 @@ void asteroids_update( double dt )
             y  = round( a->sol.pos.y );
             px = round( a->sol.pre.x );
             py = round( a->sol.pre.y );
-            w2 = ceil( a->gfx->sw * 0.5 );
-            h2 = ceil( a->gfx->sh * 0.5 );
+            w2 = ceil( tex_sw( a->gfx ) * 0.5 );
+            h2 = ceil( tex_sh( a->gfx ) * 0.5 );
             qt_insert( &ast->qt, j, MIN( x, px ) - w2, MIN( y, py ) - h2,
                        MAX( x, px ) + w2, MAX( y, py ) + h2 );
          }
@@ -503,7 +503,7 @@ static void debris_init( Debris *deb )
 }
 
 /**
- * @brief Updates internal alues of an asteroid field.
+ * @brief Updates internal values of an asteroid field.
  */
 void asteroids_computeInternals( AsteroidAnchor *a )
 {
@@ -538,7 +538,7 @@ int asteroids_load( void )
 
    /* Load asteroid graphics. */
    asteroid_files = PHYSFS_enumerateFiles( SPOB_GFX_SPACE_PATH "asteroid/" );
-   asteroid_gfx   = array_create( glTexture   *);
+   asteroid_gfx   = array_create( glTexture * );
 
    for ( size_t i = 0; asteroid_files[i] != NULL; i++ ) {
       char file[PATH_MAX];
@@ -620,7 +620,7 @@ static int asttype_load( void )
    for ( int i = 0; i < array_size( asteroid_types ); i++ ) {
       AsteroidType     *at  = &asteroid_types[i];
       AsteroidTypeGroup grp = { .name    = strdup( at->name ),
-                                .types   = array_create( AsteroidType   *),
+                                .types   = array_create( AsteroidType * ),
                                 .weights = array_create( double ),
                                 .wtotal  = 1. };
       array_push_back( &grp.types, at );
@@ -665,11 +665,11 @@ static int asttype_parse( AsteroidType *at, const char *file )
 
    /* Set up the element. */
    memset( at, 0, sizeof( AsteroidType ) );
-   at->gfxs        = array_create( glTexture        *);
+   at->gfxs        = array_create( glTexture * );
    at->polygon     = array_create( CollPoly );
    at->material    = array_create( AsteroidReward );
    at->damage      = 100;
-   at->penetration = 100.;
+   at->penetration = FULL_PENETRATION;
    at->exp_radius  = 50.;
    at->alert_range = 7000.;
 
@@ -715,7 +715,10 @@ static int asttype_parse( AsteroidType *at, const char *file )
             if ( xml_isNode( cur, "name" ) ) {
                const char *str   = xml_get( cur );
                material.material = commodity_get( str );
-               if ( material.material->gfx_space == NULL )
+               if ( material.material == NULL )
+                  WARN( "Asteroid Type '%s' has invalid Commodity '%s'",
+                        at->name, str );
+               else if ( material.material->gfx_space == NULL )
                   WARN( _( "Asteroid Type '%s' has Commodity '%s' with no "
                            "'gfx_space'." ),
                         at->name, str );
@@ -767,7 +770,7 @@ static int asttype_parse( AsteroidType *at, const char *file )
 /**
  * @brief Loads the collision polygon for an asteroid type.
  *
- *    @param temp AsteroidType to load into.
+ *    @param temp `AsteroidType` to load into.
  *    @param buf Name of the file.
  */
 static int asteroid_loadPLG( AsteroidType *temp, const char *buf )
@@ -838,7 +841,7 @@ static int astgroup_parse( AsteroidTypeGroup *ag, const char *file )
 
    /* Set up the element. */
    memset( ag, 0, sizeof( AsteroidTypeGroup ) );
-   ag->types   = array_create( AsteroidType   *);
+   ag->types   = array_create( AsteroidType * );
    ag->weights = array_create( double );
 
    xmlr_attr_strd( parent, "name", ag->name );
@@ -880,6 +883,7 @@ void asteroids_renderOverlay( void )
    cy -= SCREEN_H / 2.;
 
    NTracingZone( _ctx, 1 );
+   gl_debugGroupStart();
 
    /* Render the debris. */
    for ( int j = 0; j < array_size( debris_stack ); j++ ) {
@@ -888,6 +892,7 @@ void asteroids_renderOverlay( void )
          debris_renderSingle( d, cx, cy );
    }
 
+   gl_debugGroupEnd();
    NTracingZoneEnd( _ctx );
 }
 
@@ -903,6 +908,7 @@ void asteroids_render( void )
    cy -= SCREEN_H / 2.;
 
    NTracingZone( _ctx, 1 );
+   gl_debugGroupStart();
 
    /* Render the asteroids & debris. */
    for ( int i = 0; i < array_size( cur_system->asteroids ); i++ ) {
@@ -931,6 +937,7 @@ void asteroids_render( void )
    /* Render gatherable stuff. */
    gatherable_render();
 
+   gl_debugGroupEnd();
    NTracingZoneEnd( _ctx );
 }
 
@@ -987,8 +994,8 @@ static void asteroid_renderSingle( const Asteroid *a )
    col   = cFontWhite;
    col.a = a->scan_alpha;
    gl_gameToScreenCoords( &nx, &ny, a->sol.pos.x, a->sol.pos.y );
-   gl_printRaw( &gl_smallFont, nx + a->gfx->sw / 2, ny - gl_smallFont.h / 2,
-                &col, -1., _( at->scanned_msg ) );
+   gl_printRaw( &gl_smallFont, nx + tex_sw( a->gfx ) / 2,
+                ny - gl_smallFont.h / 2, &col, -1., _( at->scanned_msg ) );
    /*
    for (int i=0; i<array_size(at->material); i++) {
       AsteroidReward *mat = &at->material[i];
@@ -1006,6 +1013,9 @@ static void asteroid_renderSingle( const Asteroid *a )
  */
 static void debris_renderSingle( const Debris *d, double cx, double cy )
 {
+   if ( d->alpha <= 0. )
+      return;
+
    const double   scale = 0.5;
    const glColour col   = COL_ALPHA( cInert, d->alpha );
 
@@ -1020,7 +1030,7 @@ void asteroid_initAnchor( AsteroidAnchor *ast )
 {
    memset( ast, 0, sizeof( AsteroidAnchor ) );
    ast->density  = ASTEROID_DEFAULT_DENSITY;
-   ast->groups   = array_create( AsteroidTypeGroup   *);
+   ast->groups   = array_create( AsteroidTypeGroup * );
    ast->groupsw  = array_create( double );
    ast->radius   = ASTEROID_DEFAULT_RADIUS;
    ast->maxspeed = ASTEROID_DEFAULT_MAXSPEED;
