@@ -5,18 +5,14 @@
 
 #include "outfit.h"
 
+#define FULL_PENETRATION 1000. /* Not sure if INFINITY would give issues. */
+
 /*
  * stack manipulation
  */
 int         dtype_get( const char *name );
 const char *dtype_damageTypeToStr( int type );
 
-/*
- * dtype effect loading and freeing
- */
-int  dtype_load( void );
-void dtype_free( void );
-
 /*
  * misc
  */
