@@ -56,6 +56,7 @@ static int systemL_markerAdd( lua_State *L );
 static int systemL_markerRm( lua_State *L );
 static int systemL_reputation( lua_State *L );
 static int systemL_setReputation( lua_State *L );
+static int systemL_waypoints( lua_State *L );
 static int systemL_tags( lua_State *L );
 
 static const luaL_Reg system_methods[] = {
@@ -90,6 +91,7 @@ static const luaL_Reg system_methods[] = {
    { "markerRm", systemL_markerRm },
    { "reputation", systemL_reputation },
    { "setReputation", systemL_setReputation },
+   { "waypoints", systemL_waypoints },
    { "tags", systemL_tags },
    { 0, 0 } }; /**< System metatable methods. */
 
@@ -99,7 +101,7 @@ static const luaL_Reg system_methods[] = {
  *    @param env Environment to load system library into.
  *    @return 0 on success.
  */
-int nlua_loadSystem( nlua_env env )
+int nlua_loadSystem( nlua_env *env )
 {
    nlua_register( env, SYSTEM_METATABLE, system_methods, 1 );
    return 0; /* No error */
@@ -123,7 +125,7 @@ int nlua_loadSystem( nlua_env env )
  *
  *    @param L Lua state to get system from.
  *    @param ind Index position of system.
- *    @return The LuaSystem at ind.
+ *    @return LuaSystem found at ind.
  */
 LuaSystem lua_tosystem( lua_State *L, int ind )
 {
@@ -134,7 +136,7 @@ LuaSystem lua_tosystem( lua_State *L, int ind )
  *
  *    @param L Lua state to get system from.
  *    @param ind Index position of system.
- *    @return The LuaSystem at ind.
+ *    @return LuaSystem found at ind.
  */
 LuaSystem luaL_checksystem( lua_State *L, int ind )
 {
@@ -228,7 +230,7 @@ static int systemL_cur( lua_State *L )
 /**
  * @brief Gets a system.
  *
- * Behaves differently depending on what you pass as param: <br/>
+ * Behaves differently depending on what you pass as parameter: <br/>
  *    - string : Gets the system by raw (untranslated) name. <br/>
  *    - spob : Gets the system by spob. <br/>
  *
@@ -236,7 +238,7 @@ static int systemL_cur( lua_State *L )
  * @usage sys = system.get( "Gamma Polaris" ) -- Gets the system by name.
  *
  *    @luatparam string|Spob param Read description for details.
- *    @luatreturn System System matching param.
+ *    @luatreturn System System matching parameter.
  * @luafunc get
  */
 static int systemL_get( lua_State *L )
@@ -434,17 +436,18 @@ static int systemL_interference( lua_State *L )
  *    - string : Gets distance to system matching name.
  *    - system : Gets distance to system
  *
- * @usage d = sys:jumpDist() -- Distance the current system to sys.
- * @usage d = sys:jumpDist( "Draygar" ) -- Distance from sys to system Draygar.
- * @usage d = sys:jumpDist( another_sys ) -- Distance from sys to another_sys.
+ * @usage d = sys:jumpDist() -- Distance the current system to `sys`.
+ * @usage d = sys:jumpDist( "Draygar" ) -- Distance from `sys` to `"Draygar"`.
+ * @usage d = sys:jumpDist( another_sys ) -- Distance from `sys` to
+ * `another_sys`.
  *
  *    @luatparam System s Starting system.
- *    @luatparam nil|string|Goal system param See description.
+ *    @luatparam nil|string|system goal Goal system parameter, see description.
  *    @luatparam[opt=false] boolean hidden Whether or not to consider hidden
  * jumps.
  *    @luatparam[opt=false] boolean known Whether or not to consider only jumps
  * known by the player.
- *    @luatreturn number Number of jumps to system or math.huge if no path
+ *    @luatreturn number Number of jumps to system or `math.huge` if no path
  * found.
  * @luafunc jumpDist
  */
@@ -494,14 +497,14 @@ static int systemL_jumpdistance( lua_State *L )
  * name.</li> <li>system : Gets path to system</li>
  * </ul>
  *
- * @usage jumps = sys:jumpPath( system.cur() ) -- Path from sys to current
+ * @usage jumps = sys:jumpPath( system.cur() ) -- Path from `sys` to current
  * system.
- * @usage jumps = sys:jumpPath( "Draygar" ) -- Path from sys to Draygar.
- * @usage jumps = system.jumpPath( "Draygar", another_sys ) -- Path from Draygar
- * to another_sys.
+ * @usage jumps = sys:jumpPath( "Draygar" ) -- Path from `sys` to `"Draygar"`.
+ * @usage jumps = system.jumpPath( "Draygar", another_sys ) -- Path from
+ * `"Draygar"` to `another_sys`.
  *
  *    @luatparam System s Starting system.
- *    @luatparam System goal Goal system param See description.
+ *    @luatparam nil|string|system goal Goal system parameter, see description.
  *    @luatparam[opt=false] boolean hidden Whether or not to consider hidden
  * jumps.
  *    @luatreturn {Jump,...} Table of jumps.
@@ -675,7 +678,7 @@ static int systemL_addGatherable( lua_State *L )
    unsigned int player_only;
    Commodity   *commodity;
    vec2        *pos, *vel;
-   vec2         zero = { .x = 0., .y = 0., .mod = 0., .angle = 0. };
+   vec2         zero = { .x = 0., .y = 0. };
    double       lifelength;
 
    /* Handle parameters. */
@@ -864,7 +867,7 @@ static int systemL_isknown( lua_State *L )
  *    @luatparam System  s System to set known.
  *    @luatparam[opt=false] boolean b Whether or not to set as known.
  *    @luatparam[opt=false] boolean r Whether or not to iterate over the
- * system's spobs and jump points.
+ * system's spobs and jump points and set them as known too.
  * @luafunc setKnown
  */
 static int systemL_setknown( lua_State *L )
@@ -927,7 +930,7 @@ static int systemL_hidden( lua_State *L )
  *
  *    @luatparam System s System to check if the player knows.
  *    @luatparam boolean hide Whether or not to hide the system.
- * @luafunc hidden
+ * @luafunc setHidden
  */
 static int systemL_setHidden( lua_State *L )
 {
@@ -960,8 +963,8 @@ static int systemL_markerClear( lua_State *L )
 /**
  * @brief Adds a system marker.
  *
- * @usage mrk_id = system.markerAdd( vec2.new( 50, 30 ), "Hello" ) -- Creates a
- * marker at (50,30)
+ * @usage marker_id = system.markerAdd( vec2.new( 50, 30 ), "Hello" ) -- Creates
+ * a marker at (50,30)
  *
  *    @luatparam Vec2 v Position to display marker at.
  *    @luatparam[opt] string str String to display next to marker.
@@ -994,7 +997,7 @@ static int systemL_markerAdd( lua_State *L )
 /**
  * @brief Removes a system marker.
  *
- * @usage system.markerRm( mrk_id ) -- Removes a marker by mrk_id
+ * @usage system.markerRm( marker_id ) -- Removes a marker by marker_id
  *
  *    @luatparam number id ID of the marker to remove.
  * @luafunc markerRm
@@ -1061,10 +1064,50 @@ static int systemL_setReputation( lua_State *L )
    return 0;
 }
 
+/**
+ * @brief Gets the system waypoints
+ *
+ * @usage for k,w in pairs(system.cur():waypoints()) do ... end
+ * @usage system.cur():waypoints("waypoint_name")
+ *
+ *    @luatparam System s System to get waypoints of.
+ *    @luatparam[opt=nil] string name Name of the waypoint to get. Returns a
+ * Vec2 if set and a table otherwise.
+ *    @luatreturn table|Vec2 Table of waypoints where the name is the key and
+ * the Vec2 position is the value or a Vec2 position if a string is passed as
+ * the second parameter.
+ * @luafunc waypoints
+ */
+static int systemL_waypoints( lua_State *L )
+{
+   const StarSystem *s = luaL_validsystem( L, 1 );
+
+   if ( !lua_isnoneornil( L, 2 ) ) {
+      const char *name = luaL_checkstring( L, 2 );
+      for ( int i = 0; i < array_size( s->waypoints ); i++ ) {
+         const Waypoint *wp = &s->waypoints[i];
+         if ( strcmp( wp->name, name ) == 0 ) {
+            lua_pushvector( L, wp->pos );
+            return 1;
+         }
+      }
+      WARN( _( "Waypoint '%s' not found for system '%s'!" ), name, s->name );
+      return 0;
+   }
+
+   lua_newtable( L );
+   for ( int i = 0; i < array_size( s->waypoints ); i++ ) {
+      const Waypoint *wp = &s->waypoints[i];
+      lua_pushvector( L, wp->pos );
+      lua_setfield( L, -2, wp->name );
+   }
+   return 1;
+}
+
 /**
  * @brief Gets the system tags.
  *
- * @usage if system.cur():tags["fancy"] then -- Has "fancy" tag
+ * @usage if system.cur():tags()["fancy"] then -- Has "fancy" tag
  *
  *    @luatparam System s System to get tags of.
  *    @luatparam[opt=nil] string tag Tag to check if exists.
