@@ -8,17 +8,12 @@
 #include "nlua.h"
 #include "opengl_tex.h"
 #include "shipstats.h"
+#include "sound.h"
 #include "spfx.h"
 
 /*
  * properties
  */
-#define outfit_isProp( o, p )                                                  \
-   ( ( o )->properties & ( p ) ) /**< Checks an outfit for property. */
-#define outfit_setProp( o, p )                                                 \
-   ( ( o )->properties |= ( p ) ) /**< Sets property. */
-#define outfit_rmProp( o, p )                                                  \
-   ( ( o )->properties &= ~( p ) ) /**< Removes property. */
 /* property flags */
 #define OUTFIT_PROP_UNIQUE                                                     \
    ( 1 << 0 ) /**< Unique item (can only have one). Not sellable.*/
@@ -55,6 +50,13 @@
    ( 1 << 15 ) /**< The outfit needs to load graphics. */
 #define OUTFIT_PROP_STEALTH_ON                                                 \
    ( 1 << 16 ) /**< The outfit does not get turned off by stealth. */
+#define OUTFIT_PROP_HIDESTATS                                                  \
+   ( 1 << 17 ) /**< Hide the outfit shipstats from Lua stuff in the            \
+                  descriptions. */
+// We use a core property obtained from tags for now as we need a way to
+// distinguish them
+// TODO remove when we use a more flexible / better tab system
+#define OUTFIT_PROP_CORE ( 1 << 18 ) /**< Outfit is a core. */
 
 /* Outfit filter labels. [Doc comments are also translator notes and must
  * precede the #define.] */
@@ -71,11 +73,6 @@
  * tab/column title. */
 #define OUTFIT_LABEL_CORE N_( "#oCore" )
 
-/*
- * Needed because some outfittypes call other outfits.
- */
-struct Outfit_;
-
 /**
  * @brief Different types of existing outfits.
  *
@@ -187,25 +184,21 @@ typedef struct OutfitBoltData_ {
    Damage dmg;     /**< Damage done. */
    double radius;  /**< Explosion radius .*/
 
-   double heatup;     /**< How long it should take for the weapon to heat up
-                         (approx). */
-   double heat;       /**< Heat per shot. */
    double trackmin;   /**< Ewarfare minimal tracking. */
    double trackmax;   /**< Ewarfare maximal (optimal) tracking. */
    double swivel;     /**< Amount of swivel (semiarc in radians of deviation the
                          weapon can correct). */
-   double dispersion; /**< Angle amount to spread particles around independent
-                         of heat. */
+   double dispersion; /**< Angle amount to spread particles around. */
    double speed_dispersion; /**< Dispersion, but for speed. */
    int    shots;            /**< Number of particles shot when fired. */
    int    mining_rarity;    /**< Maximum mining rarity the weapon can mine. */
 
    /* Sound and graphics. */
-   OutfitGFX gfx;         /**< Rendering information. */
-   int       sound;       /**< Sound to play on shoot.*/
-   int       sound_hit;   /**< Sound to play on hit. */
-   int       spfx_armour; /**< special effect on hit. */
-   int       spfx_shield; /**< special effect on hit. */
+   OutfitGFX    gfx;         /**< Rendering information. */
+   const Sound *sound;       /**< Sound to play on shoot.*/
+   const Sound *sound_hit;   /**< Sound to play on hit. */
+   int          spfx_armour; /**< special effect on hit. */
+   int          spfx_shield; /**< special effect on hit. */
 } OutfitBoltData;
 
 /**
@@ -223,22 +216,19 @@ typedef struct OutfitBeamData_ {
    double turn;       /**< How fast it can turn. Only for turrets, in rad/s. */
    double energy;     /**< Amount of energy it drains (per second). */
    Damage dmg;        /**< Damage done. */
-   double heatup;     /**< How long it should take for the weapon to heat up
-                         (approx). */
-   double heat;       /**< Heat per second. */
    double swivel;     /**< Amount of swivel (semiarc in radians of deviation the
                          weapon can correct). */
    int mining_rarity; /**< Maximum mining rarity the weapon can mine. */
 
    /* Graphics and sound. */
-   glColour colour;       /**< Colour to use for the shader. */
-   GLfloat  width;        /**< Width of the beam. */
-   GLuint   shader;       /**< Shader subroutine to use. */
-   int      spfx_armour;  /**< special effect on hit */
-   int      spfx_shield;  /**< special effect on hit */
-   int      sound_warmup; /**< Sound to play when warming up. @todo use. */
-   int      sound;        /**< Sound to play. */
-   int      sound_off;    /**< Sound to play when turning off. */
+   glColour     colour;       /**< Colour to use for the shader. */
+   GLfloat      width;        /**< Width of the beam. */
+   GLuint       shader;       /**< Shader subroutine to use. */
+   int          spfx_armour;  /**< special effect on hit */
+   int          spfx_shield;  /**< special effect on hit */
+   const Sound *sound_warmup; /**< Sound to play when warming up. @todo use. */
+   const Sound *sound;        /**< Sound to play. */
+   const Sound *sound_off;    /**< Sound to play when turning off. */
 } OutfitBeamData;
 
 /**
@@ -259,8 +249,7 @@ typedef struct OutfitLauncherData_ {
    double arc;        /**< Semi-angle of the arc which it will lock on in. */
    double swivel;     /**< Amount of swivel (semiarc in radians of deviation the
                          weapon can correct when launched). */
-   double dispersion; /**< Angle amount to spread particles around independent
-                         of heat. */
+   double dispersion; /**< Angle amount to spread particles around. */
    double speed_dispersion; /**< Dispersion, but for speed. */
    int    shots;            /**< Number of particles shot when fired. */
    int    mining_rarity;    /**< Maximum mining rarity the weapon can mine. */
@@ -283,8 +272,8 @@ typedef struct OutfitLauncherData_ {
    double dmg_absorb; /**< Damage absorption. */
 
    OutfitGFX        gfx;         /**< Rendering information. */
-   int              sound;       /**< sound to play */
-   int              sound_hit;   /**< Sound to play on hit. */
+   const Sound     *sound;       /**< sound to play */
+   const Sound     *sound_hit;   /**< Sound to play on hit. */
    int              spfx_armour; /**< special effect on hit */
    int              spfx_shield; /**< special effect on hit */
    const TrailSpec *trail_spec;  /**< Trail style if applicable, else NULL. */
@@ -312,31 +301,29 @@ typedef struct OutfitModificationData_ {
  */
 typedef struct OutfitAfterburnerData_ {
    /* Internal properties. */
-   double rumble;     /**< Percent of rumble */
-   int    sound_on;   /**< Sound of the afterburner turning on */
-   int    sound;      /**< Sound of the afterburner being on */
-   int    sound_off;  /**< Sound of the afterburner turning off */
-   double accel;      /**< Percent of accel increase based on ship base. */
-   double speed;      /**< Percent of speed to increase based on ship base. */
-   double energy;     /**< Energy usage while active */
-   double mass_limit; /**< Limit at which effectiveness starts to drop. */
-   double heatup;     /**< How long it takes for the afterburner to overheat. */
-   double heat;       /**< Heat per second. */
+   double       rumble;    /**< Percent of rumble */
+   const Sound *sound_on;  /**< Sound of the afterburner turning on */
+   const Sound *sound;     /**< Sound of the afterburner being on */
+   const Sound *sound_off; /**< Sound of the afterburner turning off */
+   double       accel;     /**< Percent of accel increase based on ship base. */
+   double       speed;  /**< Percent of speed to increase based on ship base. */
+   double       energy; /**< Energy usage while active */
+   double       mass_limit; /**< Limit at which effectiveness starts to drop. */
 } OutfitAfterburnerData;
 
-struct Ship_; /* Bit of a horrible hack to allow us to avoid circular
+struct Ship; /* Bit of a horrible hack to allow us to avoid circular
                  definitions. */
 /**
  * @brief Represents a fighter bay.
  */
 typedef struct OutfitFighterBayData_ {
-   char               *shipname;    /**< Name of the ships to use as ammo. */
-   const struct Ship_ *ship;        /**< Ship to use as ammo. */
-   double              ship_mass;   /**< Mass of a fighter. */
-   double              delay;       /**< Delay between launches. */
-   int                 amount;      /**< Amount of ammo it can store. */
-   double              reload_time; /**< Time it takes to reload 1 ammo. */
-   int                 sound;       /**< Sound to use when launching. */
+   char              *shipname;    /**< Name of the ships to use as ammo. */
+   const struct Ship *ship;        /**< Ship to use as ammo. */
+   double             ship_mass;   /**< Mass of a fighter. */
+   double             delay;       /**< Delay between launches. */
+   int                amount;      /**< Amount of ammo it can store. */
+   double             reload_time; /**< Time it takes to reload 1 ammo. */
+   const Sound       *sound;       /**< Sound to use when launching. */
 } OutfitFighterBayData;
 
 /* Forward declaration */
@@ -349,6 +336,8 @@ typedef struct OutfitMapData_s OutfitMapData_t;
 typedef struct OutfitLocalMapData_ {
    double jump_detect; /**< Ability to detect jumps. */
    double spob_detect; /**< Ability to detect spobs. */
+   int range; /**< Distance at which applied. 0 only applies to current system.
+               */
 } OutfitLocalMapData;
 
 /**
@@ -369,7 +358,7 @@ typedef struct OutfitLicenseData_ {
 /**
  * @brief A ship outfit, depends radically on the type.
  */
-typedef struct Outfit_ {
+typedef struct Outfit {
    char *name;      /**< Name of the outfit. */
    char *typename;  /**< Overrides the base type. */
    char *shortname; /**< Shorter version of the name for GUI and such. */
@@ -377,15 +366,16 @@ typedef struct Outfit_ {
    char *filename;  /**< File data was loaded from. */
 
    /* General specs */
-   OutfitSlot slot;    /**< Slot the outfit fits into. */
-   char      *license; /**< Licenses needed to buy it. */
-   char      *cond;    /**< Conditional Lua string. */
-   char      *condstr; /**< Human readable description of the conditional. */
-   double     mass;    /**< How much weapon capacity is needed. */
-   double     cpu;     /**< CPU usage. */
-   char      *limit;   /**< Name to limit to one per ship (ignored if NULL). */
-   int       *illegalto;  /**< Factions this outfit is illegal to. */
-   char     **illegaltoS; /**< Temporary buffer to set up illegality. */
+   OutfitSlot   slot;       /**< Slot the outfit fits into. */
+   unsigned int spid_extra; /**< Can also fit this slot. */
+   char        *license;    /**< Licenses needed to buy it. */
+   char        *cond;       /**< Conditional Lua string. */
+   char        *condstr; /**< Human readable description of the conditional. */
+   double       mass;    /**< How much weapon capacity is needed. */
+   double       cpu;     /**< CPU usage. */
+   char        *limit; /**< Name to limit to one per ship (ignored if NULL). */
+   int         *illegalto;  /**< Factions this outfit is illegal to. */
+   char       **illegaltoS; /**< Temporary buffer to set up illegality. */
 
    /* Store stuff */
    credits_t price;       /**< Base sell price. */
@@ -398,13 +388,7 @@ typedef struct Outfit_ {
    glTexture  *gfx_store;      /**< Store graphic. */
    glTexture **gfx_overlays;   /**< Array (array.h): Store overlay graphics. */
 
-   /* Heat limits. */
-   double overheat_min; /**< Temperature at which the outfit BEGINS to
-                           overheat(K). */
-   double overheat_max; /**< Temperature at which the outfit overheats (K). */
-
    unsigned int properties; /**< Properties stored bitwise. */
-   unsigned int group; /**< Weapon group to use when autoweap is enabled. */
 
    /* Stats. */
    ShipStatList *stats; /**< Stat list. */
@@ -413,23 +397,25 @@ typedef struct Outfit_ {
    char **tags; /**< Outfit tags. */
 
    /* Lua function references. Set to LUA_NOREF if not used. */
-   char *lua_file; /**< Lua File. */
-   nlua_env
+   char *lua_file;   /**< Lua File. */
+   char *lua_inline; /**< Inline Lua. */
+   nlua_env *
       lua_env; /**< Lua environment. Shared for each outfit to allow globals. */
    int lua_descextra; /**< Run to get the extra description status. */
-   int
-      lua_onadd; /**< Run when added to a pilot or player swaps to this ship. */
-   int lua_onremove; /**< Run when removed to a pilot or when player swaps away
-                        from this ship. */
-   int lua_init;     /**< Run when pilot enters a system. */
-   int lua_cleanup;  /**< Run when the pilot is erased. */
-   int lua_update;   /**< Run periodically. */
-   int lua_ontoggle; /**< Run when toggled. */
-   int lua_onshoot;  /**< Run when shooting. */
-   int lua_onhit;    /**< Run when pilot takes damage. */
-   int lua_outofenergy;  /**< Run when the pilot runs out of energy. */
-   int lua_onshootany;   /**< Run when pilot shoots ANY weapon. */
-   int lua_onstealth;    /**< Run when pilot toggles stealth. */
+   int lua_onadd; /**< Run when added to a pilot or player adds this outfit. */
+   int lua_onremove; /**< Run when removed to a pilot or when player removes
+                                                this outfit. */
+   int lua_onoutfitchange; /**< Run when any outfit is changed on the ship (not
+                                                             just this one. */
+   int lua_init;           /**< Run when pilot enters a system. */
+   int lua_cleanup;        /**< Run when the pilot is erased. */
+   int lua_update;         /**< Run periodically. */
+   int lua_ontoggle;       /**< Run when toggled. */
+   int lua_onshoot;        /**< Run when shooting. */
+   int lua_onhit;          /**< Run when pilot takes damage. */
+   int lua_outofenergy;    /**< Run when the pilot runs out of energy. */
+   int lua_onshootany;     /**< Run when pilot shoots ANY weapon. */
+   int lua_onstealth;      /**< Run when pilot toggles stealth. */
    int lua_onscanned;    /**< Run when the pilot is scanned by another pilot. */
    int lua_onscan;       /**< Run when the pilot scans another pilot. */
    int lua_cooldown;     /**< Run when cooldown is started or stopped. */
@@ -439,6 +425,9 @@ typedef struct Outfit_ {
    int lua_board;        /**< Run when the player boards a ship. */
    int lua_keydoubletap; /**< Run when a key is double tapped. */
    int lua_keyrelease;   /**< Run when a key is released. */
+   int lua_message;      /**< Run when an outfit receives a message via Lua. */
+   int lua_ondeath;      /**< Run when pilot is killed. */
+   int lua_onanyimpact;  /**< Run when any weapon hits the enemy. */
    /* Weapons only. */
    int lua_onimpact; /**< Run when weapon hits the enemy. */
    int lua_onmiss;   /**< Run when weapon particle expires. */
@@ -467,38 +456,96 @@ typedef struct Outfit_ {
 /*
  * Access stuff.
  */
-int           outfit_gfxStoreLoaded( const Outfit *o );
-int           outfit_gfxStoreLoadNeeded( void );
-int           outfit_gfxStoreLoad( Outfit *o );
-const Outfit *outfit_get( const char *name );
-const Outfit *outfit_getW( const char *name );
-const Outfit *outfit_getAll( void );
-int           outfit_compareTech( const void *outfit1, const void *outfit2 );
+int            outfit_gfxStoreLoaded( const Outfit *o );
+int            outfit_gfxStoreLoadNeeded( void );
+int            outfit_gfxStoreLoad( Outfit *o );
+const Outfit  *outfit_get( const char *name );
+const Outfit  *outfit_getW( const char *name );
+const Outfit **outfit_getAll( void );
+Outfit        *outfit_getAll_rust( void );
+int            outfit_compareTech( const void *outfit1, const void *outfit2 );
+int            outfit_isProp( const Outfit *o, unsigned int prop );
+void           outfit_setProp( Outfit *o, unsigned int prop );
+void           outfit_rmProp( Outfit *o, unsigned int prop );
+double         outfit_mass( const Outfit *o );
+double         outfit_massAmmo( const Outfit *o );
+const char    *outfit_license( const Outfit *o );
+credits_t      outfit_price( const Outfit *o );
+const char    *outfit_getPrice( const Outfit *outfit, unsigned int q,
+                                credits_t *price, int *canbuy, int *cansell,
+                                char **player_has );
 /* outfit types */
-int         outfit_isActive( const Outfit *o );
-int         outfit_isToggleable( const Outfit *o );
-int         outfit_isWeapon( const Outfit *o );
-int         outfit_isForward( const Outfit *o );
-int         outfit_isBolt( const Outfit *o );
-int         outfit_isBeam( const Outfit *o );
-int         outfit_isLauncher( const Outfit *o );
-int         outfit_isAmmo( const Outfit *o );
-int         outfit_isSeeker( const Outfit *o );
-int         outfit_isTurret( const Outfit *o );
-int         outfit_isMod( const Outfit *o );
-int         outfit_isAfterburner( const Outfit *o );
-int         outfit_isFighterBay( const Outfit *o );
-int         outfit_isMap( const Outfit *o );
-int         outfit_isLocalMap( const Outfit *o );
-int         outfit_isGUI( const Outfit *o );
-int         outfit_isLicense( const Outfit *o );
-int         outfit_isSecondary( const Outfit *o );
-const char *outfit_getType( const Outfit *o );
-const char *outfit_getTypeBroad( const Outfit *o );
-const char *outfit_getAmmoAI( const Outfit *o );
-const char *outfit_description( const Outfit *o );
-const char *outfit_summary( const Outfit *o, int withname );
-const char *outfit_shortname( const Outfit *o );
+int            outfit_isActive( const Outfit *o );
+int            outfit_isToggleable( const Outfit *o );
+int            outfit_isWeapon( const Outfit *o );
+int            outfit_isForward( const Outfit *o );
+int            outfit_isBolt( const Outfit *o );
+int            outfit_isBeam( const Outfit *o );
+int            outfit_isLauncher( const Outfit *o );
+int            outfit_isAmmo( const Outfit *o );
+int            outfit_isSeeker( const Outfit *o );
+int            outfit_isTurret( const Outfit *o );
+int            outfit_isMod( const Outfit *o );
+int            outfit_isAfterburner( const Outfit *o );
+int            outfit_isFighterBay( const Outfit *o );
+int            outfit_isMap( const Outfit *o );
+int            outfit_isLocalMap( const Outfit *o );
+int            outfit_isGUI( const Outfit *o );
+int            outfit_isLicense( const Outfit *o );
+int            outfit_isSecondary( const Outfit *o );
+const char    *outfit_getType( const Outfit *o );
+const char    *outfit_getTypeBroad( const Outfit *o );
+const char    *outfit_getAmmoAI( const Outfit *o );
+const char    *outfit_description( const Outfit *o );
+const char    *outfit_summary( const Outfit *o, int withname );
+const char    *outfit_rawname( const Outfit *o );
+const char    *outfit_name( const Outfit *o );
+const char    *outfit_shortname( const Outfit *o );
+const char    *outfit_cond( const Outfit *o );
+const char    *outfit_condstr( const Outfit *o );
+const char    *outfit_limit( const Outfit *o );
+OutfitType     outfit_type( const Outfit *o );
+OutfitSlotType outfit_slotType( const Outfit *o );
+OutfitSlotSize outfit_slotSize( const Outfit *o );
+int            outfit_slotProperty( const Outfit *o );
+int            outfit_slotPropertyExtra( const Outfit *o );
+int            outfit_slotExclusive( const Outfit *o );
+int            outfit_rarity( const Outfit *o );
+char          *outfit_descExtra( const Outfit *o );
+char          *outfit_descRaw( const Outfit *o );
+char          *outfit_summaryRaw( const Outfit *o );
+/* Lua stuff. */
+nlua_env *outfit_luaEnv( const Outfit *o );
+int       outfit_luaDescextra( const Outfit *o );
+int       outfit_luaOnadd( const Outfit *o );
+int       outfit_luaOnremove( const Outfit *o );
+int       outfit_luaOnoutfitchange( const Outfit *o );
+int       outfit_luaInit( const Outfit *o );
+int       outfit_luaCleanup( const Outfit *o );
+int       outfit_luaUpdate( const Outfit *o );
+int       outfit_luaOntoggle( const Outfit *o );
+int       outfit_luaOnshoot( const Outfit *o );
+int       outfit_luaOnhit( const Outfit *o );
+int       outfit_luaOutofenergy( const Outfit *o );
+int       outfit_luaOnshootany( const Outfit *o );
+int       outfit_luaOnstealth( const Outfit *o );
+int       outfit_luaOnscanned( const Outfit *o );
+int       outfit_luaOnscan( const Outfit *o );
+int       outfit_luaCooldown( const Outfit *o );
+int       outfit_luaLand( const Outfit *o );
+int       outfit_luaTakeoff( const Outfit *o );
+int       outfit_luaJumpin( const Outfit *o );
+int       outfit_luaBoard( const Outfit *o );
+int       outfit_luaKeydoubletap( const Outfit *o );
+int       outfit_luaKeyrelease( const Outfit *o );
+int       outfit_luaMessage( const Outfit *o );
+int       outfit_luaOndeath( const Outfit *o );
+int       outfit_luaOnanyimpact( const Outfit *o );
+int       outfit_luaOnImpact( const Outfit *o );
+int       outfit_luaOnMiss( const Outfit *o );
+int       outfit_luaPrice( const Outfit *o );
+int       outfit_luaBuy( const Outfit *o );
+int       outfit_luaSell( const Outfit *o );
 
 /*
  * Search.
@@ -520,34 +567,79 @@ int outfit_filterOther( const Outfit *o );
  */
 const char     *outfit_slotName( const Outfit *o );
 const char     *slotName( const OutfitSlotType o );
-const char     *outfit_slotSize( const Outfit *o );
+const char     *outfit_slotSizeName( const Outfit *o );
 const char     *slotSize( const OutfitSlotSize o );
-const glColour *outfit_slotSizeColour( const OutfitSlot *os );
-char            outfit_slotSizeColourFont( const OutfitSlot *os );
-char            outfit_slotTypeColourFont( const OutfitSlot *os );
+const glColour *outfit_slotSizeColour( OutfitSlotSize size );
+char            outfit_slotSizeColourFont( OutfitSlotSize size );
+char            outfit_slotTypeColourFont( OutfitSlotType type );
 size_t outfit_getNameWithClass( const Outfit *outfit, char *buf, size_t size );
-OutfitSlotSize   outfit_toSlotSize( const char *s );
-const OutfitGFX *outfit_gfx( const Outfit *o );
-const CollPoly  *outfit_plg( const Outfit *o );
-int              outfit_spfxArmour( const Outfit *o );
-int              outfit_spfxShield( const Outfit *o );
-const Damage    *outfit_damage( const Outfit *o );
-double           outfit_radius( const Outfit *o );
-double           outfit_delay( const Outfit *o );
-int              outfit_amount( const Outfit *o );
-double           outfit_energy( const Outfit *o );
-double           outfit_heat( const Outfit *o );
-double           outfit_cpu( const Outfit *o );
-double           outfit_range( const Outfit *o );
-double           outfit_speed( const Outfit *o );
-double           outfit_swivel( const Outfit *o );
-double           outfit_spin( const Outfit *o );
-double           outfit_trackmin( const Outfit *o );
-double           outfit_trackmax( const Outfit *o );
-int              outfit_miningRarity( const Outfit *o );
-int              outfit_sound( const Outfit *o );
-int              outfit_soundHit( const Outfit *o );
-double           outfit_ammoMass( const Outfit *o );
+OutfitSlotSize      outfit_toSlotSize( const char *s );
+const OutfitGFX    *outfit_gfx( const Outfit *o );
+const glTexture    *outfit_gfxStore( const Outfit *o );
+const glTexture   **outfit_gfxOverlays( const Outfit *o );
+const CollPoly     *outfit_plg( const Outfit *o );
+const ShipStatList *outfit_stats( const Outfit *o );
+int                 outfit_spfxArmour( const Outfit *o );
+int                 outfit_spfxShield( const Outfit *o );
+const Damage       *outfit_damage( const Outfit *o );
+double              outfit_radius( const Outfit *o );
+double              outfit_delay( const Outfit *o );
+int                 outfit_amount( const Outfit *o );
+int                 outfit_reloadTime( const Outfit *o );
+double              outfit_energy( const Outfit *o );
+double              outfit_cpu( const Outfit *o );
+double              outfit_rangeRaw( const Outfit *o );
+double              outfit_range( const Outfit *o );
+double              outfit_speed( const Outfit *o );
+double              outfit_width( const Outfit *o );
+const glColour     *outfit_colour( const Outfit *o );
+double              outfit_falloff( const Outfit *o );
+double              outfit_turn( const Outfit *o );
+double              outfit_swivel( const Outfit *o );
+double              outfit_spin( const Outfit *o );
+double              outfit_trackmin( const Outfit *o );
+double              outfit_trackmax( const Outfit *o );
+int                 outfit_miningRarity( const Outfit *o );
+const Sound        *outfit_sound( const Outfit *o );
+const Sound        *outfit_soundHit( const Outfit *o );
+const Sound        *outfit_soundOff( const Outfit *o );
+double              outfit_ammoMass( const Outfit *o );
+int                 outfit_shots( const Outfit *o );
+double              outfit_dispersion( const Outfit *o );
+double              outfit_speed_dispersion( const Outfit *o );
+const char         *outfit_gui( const Outfit *o );
+const char         *outfit_licenseProvides( const Outfit *o );
+double              outfit_lmapJumpDetect( const Outfit *o );
+double              outfit_lmapSpobDetect( const Outfit *o );
+int                 outfit_lmapRange( const Outfit *o );
+double              outfit_afterburnerMassLimit( const Outfit *o );
+double              outfit_afterburnerSpeed( const Outfit *o );
+double              outfit_afterburnerAccel( const Outfit *o );
+const Sound        *outfit_afterburnerSound( const Outfit *o );
+const Sound        *outfit_afterburnerSoundOn( const Outfit *o );
+const Sound        *outfit_afterburnerSoundOff( const Outfit *o );
+double              outfit_afterburnerRumble( const Outfit *o );
+double              outfit_launcherSpeed( const Outfit *o );
+double              outfit_launcherSpeedMax( const Outfit *o );
+double              outfit_launcherTurn( const Outfit *o );
+double              outfit_launcherAccel( const Outfit *o );
+double              outfit_launcherResist( const Outfit *o );
+OutfitAmmoAI        outfit_launcherAI( const Outfit *o );
+double              outfit_launcherArc( const Outfit *o );
+double              outfit_launcherDuration( const Outfit *o );
+double              outfit_launcherArmour( const Outfit *o );
+double              outfit_launcherAbsorb( const Outfit *o );
+double              outfit_launcherLockon( const Outfit *o );
+double              outfit_launcherIFLockon( const Outfit *o );
+const OutfitGFX    *outfit_launcherGFX( const Outfit *o );
+const TrailSpec    *outfit_launcherTrailSpec( const Outfit *o );
+double              outfit_launcherTrailOffset( const Outfit *o );
+const struct Ship  *outfit_bayShip( const Outfit *o );
+GLuint              outfit_beamShader( const Outfit *o );
+double              outfit_beamMinDelay( const Outfit *o );
+double              outfit_beamWarmup( const Outfit *o );
+double              outfit_boltSpeed( const Outfit *o );
+
 /* Active outfits. */
 double outfit_duration( const Outfit *o );
 double outfit_cooldown( const Outfit *o );
@@ -568,4 +660,6 @@ int        outfit_fitsSlotType( const Outfit *o, const OutfitSlot *s );
 void       outfit_freeSlot( OutfitSlot *s );
 glTexture *rarity_texture( int rarity );
 int        outfit_checkIllegal( const Outfit *o, int fct );
+int       *outfit_illegalTo( const Outfit *o );
 int        outfit_licenseExists( const char *name );
+char     **outfit_tags( const Outfit *o );
